apply_power

Function apply_power 

pub async fn apply_power(
    infra: &InfraContext<'_>,
    token: &str,
    params: &ApplyPowerParams,
) -> Result<TransitionResponse, Error>
Dispatch the requested power action to the backend PCS trait.

force is ignored for PowerAction::On (the backend trait has no force parameter for the on transition).